Wufoo-Style Form (Tricky for Autofill)

# Simplified Wufoo-Style Form

A minimal form with Wufoo styling.

Success! Form submitted successfully! The secret is: dumbledore

## Form Information

Email Address
✉
Please enter a valid email address
Country
Please select your country
Event Date
Please select a date
Preferred Contact Method
Email Phone Mail
Please select a contact method
Upload Document
Click to select a file
Please select a file to upload